@@ -1,17 +1,14 @@
+import configparser
 import os
 
 import yaml
 
-try:
-    import ConfigParser as configparser
-except ImportError:
-    import configparser
-
 default_work_dir = "~/.cekit"
 
 
 class Config(object):
     """Represents Cekit configuration - behaves as Singleton"""
+
     cfg = {}
 
     @classmethod
@@ -22,14 +19,17 @@ class Config(object):
     @classmethod
     def _override_config(cls, cmdline_args):
         # Only allow command line overriding of these values if they are not the default value.
-        if cmdline_args.get('redhat'):
-            cls.cfg['common']['redhat'] = cmdline_args.get('redhat')
-        if cmdline_args.get('work_dir') and cmdline_args.get('work_dir') != default_work_dir:
-            cls.cfg['common']['work_dir'] = cmdline_args.get('work_dir')
+        if cmdline_args.get("redhat"):
+            cls.cfg["common"]["redhat"] = cmdline_args.get("redhat")
+        if (
+            cmdline_args.get("work_dir")
+            and cmdline_args.get("work_dir") != default_work_dir
+        ):
+            cls.cfg["common"]["work_dir"] = cmdline_args.get("work_dir")
 
     @classmethod
     def _load_cfg(cls, config_path):
-        """ Loads configuration from cekit config file
+        """Loads configuration from cekit config file
 
         params:
         config_path - path to a cekit config file (expanding user)
@@ -37,15 +37,20 @@ class Config(object):
         config_parser = configparser.ConfigParser()
         config_parser.read(os.path.expanduser(config_path))
         cls.cfg = config_parser._sections
-        cls.cfg['common'] = cls.cfg.get('common', {})
-        cls.cfg['common']['work_dir'] = cls.cfg.get('common').get('work_dir', default_work_dir)
-        cls.cfg['common']['redhat'] = yaml.safe_load(
-            cls.cfg.get('common', {}).get('redhat', 'False'))
-        cls.cfg['common']['fetch_url_domains'] = cls.cfg.get('common').get('fetch_url_domains')
+        cls.cfg["common"] = cls.cfg.get("common", {})
+        cls.cfg["common"]["work_dir"] = cls.cfg.get("common").get(
+            "work_dir", default_work_dir
+        )
+        cls.cfg["common"]["redhat"] = yaml.safe_load(
+            cls.cfg.get("common", {}).get("redhat", "False")
+        )
+        cls.cfg["common"]["fetch_url_domains"] = cls.cfg.get("common").get(
+            "fetch_url_domains"
+        )
 
     @classmethod
     def get(cls, *args):
-        """ Returns key value located by path of *args,
+        """Returns key value located by path of *args,
         None if Key doesn't exists,
 
         Args:
@@ -56,7 +61,9 @@ class Config(object):
         value = cls.cfg
         for arg in args:
             if arg not in value and arg != args[-1]:
-                raise KeyError("'%s' section doesnt exists in Cekit configuration!" %
-                               '/'.join(args[:-1]))
+                raise KeyError(
+                    "'%s' section doesnt exists in Cekit configuration!"
+                    % "/".join(args[:-1])
+                )
             value = value.get(arg)
         return value
